@@ -611,7 +611,7 @@ def test_apply_gufunc_axes_two_kept_coredims():
     assert c.compute().shape == (10, 20, 30, 40)
 
 
-@pytest.mark.xfail(  # type: ignore[call-overload]
+@pytest.mark.xfail(
     da._array_expr_enabled(), reason="numba doesn't tokenize deterministically"
 )
 def test_apply_gufunc_via_numba_01():
@@ -634,7 +634,7 @@ def test_apply_gufunc_via_numba_01():
     assert_eq(x, y)
 
 
-@pytest.mark.xfail(  # type: ignore[call-overload]
+@pytest.mark.xfail(
     da._array_expr_enabled(), reason="numba doesn't tokenize deterministically"
 )
 def test_apply_gufunc_via_numba_02():
@@ -683,7 +683,7 @@ def test_apply_gufunc_with_meta():
     assert_eq(expected[1], result[1])
 
 
-@pytest.mark.xfail(da._array_expr_enabled(), reason="Create our Own Scalar Class")  # type: ignore[call-overload]
+@pytest.mark.xfail(da._array_expr_enabled(), reason="Create our Own Scalar Class")
 def test_as_gufunc_with_meta():
     stack = da.ones((1, 50, 60), chunks=(1, -1, -1))
     expected = (stack, stack.max())
